@@ -1,8 +1,6 @@
 """
     Kodexa is a Python framework to enable flexible data engineering with semi-structured and unstructured documents and
     data.
-
-
 """
 from .cloud import RemoteSession, RemotePipeline, RemoteAction, KodexaPlatform
 from .connectors import FolderConnector, FileHandleConnector, UrlConnector, registered_connectors, get_connectors, \
@@ -11,6 +9,6 @@ from .extractors import *
 from .model import DocumentMetadata, ContentNode, ContentFeature, DocumentRender, SourceMetadata, \
     Document
 from .pipeline import Pipeline, PipelineStatistics, PipelineContext
-from .sinks import InMemoryDocumentSink
+from .sinks import InMemoryDocumentSink, FolderSink, KodexaPlatformSink
 from .steps import NodeTagger, TextParser, RollupTransformer, TagsToKeyValuePairExtractor
 from .stores import JsonDocumentStore, TableDataStore, DictDataStore, DataStoreHelper
