@@ -1,14 +1,13 @@
+import dataclasses
 import itertools
 import json
 import re
 import uuid
-from dataclasses import dataclass, field
 from enum import Enum
 from typing import List, Optional, Any
 
 import msgpack
 from addict import Dict
-from dataclasses_json import dataclass_json
 
 from kodexa.mixins import registry
 
@@ -1162,9 +1161,8 @@ class DocumentRender:
         return self.kodexa_render.build_html(self.document, node)
 
 
-@dataclass
-@dataclass_json
-class SourceMetadata(object):
+@dataclasses.dataclass()
+class SourceMetadata:
     """
     Class for keeping track of the original source information for a
     document
@@ -1176,7 +1174,7 @@ class SourceMetadata(object):
     created: Optional[str] = None
     connector: Optional[str] = None
     mime_type: Optional[str] = None
-    headers: dict = field(default_factory=dict)
+    headers: Optional[Dict] = None
 
 
 class Document(object):
@@ -1290,6 +1288,7 @@ class Document(object):
         """
         return {'version': Document.CURRENT_VERSION, 'metadata': self.metadata,
                 'content_node': self.content_node.to_dict() if self.content_node else None,
+                'source': dataclasses.asdict(self.source),
                 'mixins': self._mixins,
                 'exceptions': self.exceptions,
                 'log': self.log,
@@ -1318,7 +1317,8 @@ class Document(object):
             uuid.uuid5(uuid.NAMESPACE_DNS, 'kodexa.com'))
         if 'content_node' in doc_dict and doc_dict['content_node']:
             new_document.content_node = ContentNode.from_dict(new_document, doc_dict['content_node'])
-
+        if 'source' in doc_dict and doc_dict['source']:
+            new_document.source = SourceMetadata(**doc_dict['source'])
         return new_document
 
     @staticmethod
@@ -1414,6 +1414,8 @@ class Document(object):
         :rtype: Document
         """
         file_document = Document()
+        file_document.metadata.connector = 'file-handle'
+        file_document.metadata.connector_options.file = file
         file_document.source.connector = 'file-handle'
         file_document.source.original_path = file
         return file_document
@@ -1432,6 +1434,9 @@ class Document(object):
         if headers is None:
             headers = {}
         url_document = Document()
+        url_document.metadata.connector = 'url'
+        url_document.metadata.connector_options.url = url
+        url_document.metadata.connector_options.headers = headers
         url_document.source.connector = 'url'
         url_document.source.original_path = url
         url_document.source.headers = headers
