@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import inspect
 import logging
+import os
 import sys
 import traceback
 import uuid
@@ -31,7 +32,11 @@ class ContentType(Enum):
 
 class ContentObject:
 
-    def __init__(self, name="untitled", id=new_id(), content_type=ContentType.DOCUMENT, tags=[], metadata={}):
+    def __init__(self, name="untitled", id=new_id(), content_type=ContentType.DOCUMENT, tags=None, metadata=None):
+        if metadata is None:
+            metadata = {}
+        if tags is None:
+            tags = []
         self.id = id
         self.name = name
         self.content_type = content_type
@@ -188,7 +193,7 @@ class PipelineStep:
     """
 
     def __init__(self, step, enabled=False, condition=None, name=None, options=None, attach_source=False,
-                 parameterized=False):
+                 parameterized=False, cache_path=None):
         if options is None:
             options = {}
         self.step = step
@@ -197,6 +202,7 @@ class PipelineStep:
         self.enabled = enabled
         self.options = options
         self.parameterized = parameterized
+        self.cache_path = cache_path
 
         if str(type(self.step)) == "<class 'type'>":
             logging.info(f"Adding new step class {step.__name__} to pipeline {self.name}")
@@ -238,9 +244,19 @@ class PipelineStep:
             raise Exception("All steps must implement to_dict() for deployment", e)
 
     def execute(self, context, document):
+
+        if self.cache_path:
+            # Check to see if we have a cached file
+            cache_name = self.get_cache_name(document)
+            if os.path.isfile(cache_name):
+                return Document.from_kdxa(cache_name)
+
         if self.will_execute(context, document):
             try:
 
+                if self.cache_path:
+                    document.to_kdxa(self.get_cache_name(document))
+
                 context.set_current_document(document)
                 if str(type(self.step)) == "<class 'type'>":
 
@@ -258,7 +274,7 @@ class PipelineStep:
                             elif isinstance(opts, list):
                                 new_list = []
                                 for list_val in opts:
-                                    new_list.append(replace_params(list_val))
+                                    new_list.append(replace_params(list_val, params))
                                 return new_list
                             elif isinstance(opts, str):
                                 if opts.startswith('${') and opts.endswith('}'):
@@ -305,6 +321,8 @@ class PipelineStep:
         else:
             return document
 
+            return document
+
     def will_execute(self, context, document):
         if not self.enabled:
             return False
@@ -318,6 +336,11 @@ class PipelineStep:
 
         return True
 
+    def get_cache_name(self, document):
+        file_name = document.source.original_filename \
+            if document.source.original_filename is not None else document.uuid
+        return f"{self.cache_path}/{file_name}.kdxa"
+
 
 class Pipeline:
     """
@@ -354,7 +377,7 @@ class Pipeline:
         Add the store to the pipeline so that it is available to the pipeline
 
             >>> pipeline = Pipeline(FolderConnector(path='/tmp/', file_filter='example.pdf'))
-            >>> pipeline.add_store("test-store", InMemoryObjectStore())
+            >>> pipeline.add_store("test-store", TableDataStore())
 
         :param name: the name of the store (to refer to it)
         :param store: the store that should be added
@@ -364,7 +387,7 @@ class Pipeline:
         return self
 
     def add_step(self, step, name=None, enabled=True, condition=None, options=None, attach_source=False,
-                 parameterized=False):
+                 parameterized=False, cache_path=None):
         """
         Add the given step to the current pipeline
 
@@ -390,12 +413,13 @@ class Pipeline:
         :param options: options to be passed to the step if it is a simplified remote action
         :param attach_source: if step is simplified remote action this determines if we need to add the source
         :param parameterized: apply the pipeline's parameters to the options
+        :param cache_path: cache the document locally, note this is only for local pipelines
 
         """
         if options is None:
             options = {}
         self.steps.append(PipelineStep(step=step, name=name, enabled=enabled, condition=condition, options=options,
-                                       attach_source=attach_source, parameterized=parameterized))
+                                       attach_source=attach_source, parameterized=parameterized, cache_path=cache_path))
 
         return self
 
@@ -518,7 +542,7 @@ class Pipeline:
 
     @staticmethod
     def from_folder(folder_path: str, filename_filter: str = "*", recursive: bool = False, relative: bool = False,
-                    caller_path: str = get_caller_dir(), *args, **kwargs) -> Pipeline:
+                    unpack=False, caller_path: str = get_caller_dir(), *args, **kwargs) -> Pipeline:
         """
         Create a pipeline that will run against a set of local files from a folder
 
@@ -527,10 +551,12 @@ class Pipeline:
         :param recursive: Should we look recursively in sub-directories (default False)
         :param relative: Is the folder path relative to the caller (default False)
         :param caller_path: The caller path (defaults to trying to work this out from the stack)
+        :param unpack: Treat the files in the folder as KDXA documents and unpack them using from_kdxa (default False)
         :return: A new pipeline
         :rtype: Pipeline
         """
-        return Pipeline(FolderConnector(folder_path, filename_filter, recursive, relative, caller_path))
+        return Pipeline(FolderConnector(folder_path, filename_filter, recursive=recursive, relative=relative,
+                                        caller_path=caller_path, unpack=unpack))
 
     @staticmethod
     def from_store(org_slug: str, slug: str, query: str = "*") -> Pipeline:
